@@ -52,7 +52,6 @@ def display_banner(window, msg):
 class NS(hildon.Program):
     def __init__(self):
         hildon.Program.__init__(self)
-        gtk.set_application_name("ns-schedule")
         
         self.fromButton = None
         self.toButton = None
@@ -72,7 +71,9 @@ class NS(hildon.Program):
 
         self.window = hildon.StackableWindow()
         self.window.connect("delete_event", self.quit)  
+        # FIXME
         self.window.get_screen().connect("size-changed", self.drawUI)
+        self.rotation.set_mode(1)
 
         self.add_window(self.window)
        
@@ -488,10 +489,9 @@ class NS(hildon.Program):
         about.set_name("NSSchedule")
         about.set_comments("Dutch Train Journey Information")
         about.set_version("0.1")
-        about.set_copyright("Giorgos Logiotatidis")
-        about.set_email("seadog@sealabs.net")
-#        about.set_website("https://launchpad.net/maemo-stopwatch")
-        about.set_logo_icon_name("stopwatch")
+        about.set_copyright("Giorgos Logiotatidis\nseadog@sealabs.net")
+        about.set_website("https://www.sealabs.net/seadog")
+        about.set_logo_icon_name("nsschedule")
         about.connect("response", lambda x, y: x.destroy())
         about.show()
 
